package iotcloud;

import java.nio.ByteBuffer;

/**
 * This Entry records the abort sent by a given machine.
 * @author Ali Younis <ayounis@uci.edu>
 * @version 1.0
 */


class Abort extends Entry {
	private long seqnumtrans;
	private long machineid;
	private long transarbitrator;


	public Abort(Slot slot, long _seqnumtrans, long _machineid, long _transarbitrator) {
		super(slot);
		seqnumtrans = _seqnumtrans;
		machineid = _machineid;
		transarbitrator = _transarbitrator;
	}

	public long getMachineID() {
		return machineid;
	}

	public long getTransSequenceNumber() {
		return seqnumtrans;
	}

	public long getTransArbitrator() {
		return transarbitrator;
	}


	static Entry decode(Slot slot, ByteBuffer bb) {
		long seqnumtrans = bb.getLong();
		long machineid = bb.getLong();
		long transarbitrator = bb.getLong();
		return new Abort(slot, seqnumtrans, machineid, transarbitrator);
	}

	public void encode(ByteBuffer bb) {
		bb.put(Entry.TypeAbort);
		bb.putLong(seqnumtrans);
		bb.putLong(machineid);
		bb.putLong(transarbitrator);
	}

	public int getSize() {
		return (3 * Long.BYTES) + Byte.BYTES;
	}

	public byte getType() {
		return Entry.TypeAbort;
	}

	public Entry getCopy(Slot s) {
		return new Abort(s, seqnumtrans, machineid, transarbitrator);
	}
}